# Otree QVSR
A simple installable package for qvsr survey experiments.

## Installation
```
pip install otree-qvsr
```

## Usage
Python version used :: 3.10

Run ```otree devserver``` to start up the qvsr app

### Missing functionality
- [ ] Dynamically add survey questions and allocated points
- [ ] Deploy to otree hub